ChangeSet 1.1455.1.8, 2003/07/14 16:33:07-07:00, greg@kroah.com

[PATCH] PCI: remove usages of pci slot_name from the pci core code.


 drivers/pci/hotplug.c   |    2 +-
 drivers/pci/pci.c       |   10 +++++-----
 drivers/pci/pool.c      |    8 ++++----
 drivers/pci/quirks.c    |    8 ++++----
 drivers/pci/setup-bus.c |    6 +++---
 drivers/pci/setup-res.c |    8 ++++----
 6 files changed, 21 insertions(+), 21 deletions(-)


diff -Nru a/drivers/pci/hotplug.c b/drivers/pci/hotplug.c
--- a/drivers/pci/hotplug.c	Mon Jul 14 16:55:17 2003
+++ b/drivers/pci/hotplug.c	Mon Jul 14 16:55:17 2003
@@ -57,7 +57,7 @@
 
 	envp[i++] = scratch;
 	length += snprintf (scratch, buffer_size - length, "PCI_SLOT_NAME=%s",
-			    pdev->slot_name);
+			    pci_name(pdev));
 	if ((buffer_size - length <= 0) || (i >= num_envp))
 		return -ENOMEM;
 
diff -Nru a/drivers/pci/pci.c b/drivers/pci/pci.c
--- a/drivers/pci/pci.c	Mon Jul 14 16:55:17 2003
+++ b/drivers/pci/pci.c	Mon Jul 14 16:55:17 2003
@@ -506,7 +506,7 @@
 		pci_resource_flags(pdev, bar) & IORESOURCE_IO ? "I/O" : "mem",
 		bar + 1, /* PCI BAR # */
 		pci_resource_len(pdev, bar), pci_resource_start(pdev, bar),
-		pdev->slot_name);
+		pci_name(pdev));
 	return -EBUSY;
 }
 
@@ -555,7 +555,7 @@
 		pci_resource_flags(pdev, i) & IORESOURCE_IO ? "I/O" : "mem",
 		i + 1, /* PCI BAR # */
 		pci_resource_len(pdev, i), pci_resource_start(pdev, i),
-		pdev->slot_name);
+		pci_name(pdev));
 	while(--i >= 0)
 		pci_release_region(pdev, i);
 		
@@ -576,7 +576,7 @@
 
 	pci_read_config_word(dev, PCI_COMMAND, &cmd);
 	if (! (cmd & PCI_COMMAND_MASTER)) {
-		DBG("PCI: Enabling bus mastering for device %s\n", dev->slot_name);
+		DBG("PCI: Enabling bus mastering for device %s\n", pci_name(dev));
 		cmd |= PCI_COMMAND_MASTER;
 		pci_write_config_word(dev, PCI_COMMAND, cmd);
 	}
@@ -620,7 +620,7 @@
 		return 0;
 
 	printk(KERN_WARNING "PCI: cache line size of %d is not supported "
-	       "by device %s\n", pci_cache_line_size << 2, dev->slot_name);
+	       "by device %s\n", pci_cache_line_size << 2, pci_name(dev));
 
 	return -EINVAL;
 }
@@ -653,7 +653,7 @@
 
 	pci_read_config_word(dev, PCI_COMMAND, &cmd);
 	if (! (cmd & PCI_COMMAND_INVALIDATE)) {
-		DBG("PCI: Enabling Mem-Wr-Inval for device %s\n", dev->slot_name);
+		DBG("PCI: Enabling Mem-Wr-Inval for device %s\n", pci_name(dev));
 		cmd |= PCI_COMMAND_INVALIDATE;
 		pci_write_config_word(dev, PCI_COMMAND, cmd);
 	}
diff -Nru a/drivers/pci/pool.c b/drivers/pci/pool.c
--- a/drivers/pci/pool.c	Mon Jul 14 16:55:17 2003
+++ b/drivers/pci/pool.c	Mon Jul 14 16:55:17 2003
@@ -233,7 +233,7 @@
 				struct pci_page, page_list);
 		if (is_page_busy (pool->blocks_per_page, page->bitmap)) {
 			printk (KERN_ERR "pci_pool_destroy %s/%s, %p busy\n",
-				pool->dev ? pool->dev->slot_name : NULL,
+				pool->dev ? pci_name(pool->dev) : NULL,
 				pool->name, page->vaddr);
 			/* leak the still-in-use consistent memory */
 			list_del (&page->page_list);
@@ -359,7 +359,7 @@
 
 	if ((page = pool_find_page (pool, dma)) == 0) {
 		printk (KERN_ERR "pci_pool_free %s/%s, %p/%lx (bad dma)\n",
-			pool->dev ? pool->dev->slot_name : NULL,
+			pool->dev ? pci_name(pool->dev) : NULL,
 			pool->name, vaddr, (unsigned long) dma);
 		return;
 	}
@@ -372,13 +372,13 @@
 #ifdef	CONFIG_DEBUG_SLAB
 	if (((dma - page->dma) + (void *)page->vaddr) != vaddr) {
 		printk (KERN_ERR "pci_pool_free %s/%s, %p (bad vaddr)/%Lx\n",
-			pool->dev ? pool->dev->slot_name : NULL,
+			pool->dev ? pci_name(pool->dev) : NULL,
 			pool->name, vaddr, (unsigned long long) dma);
 		return;
 	}
 	if (page->bitmap [map] & (1UL << block)) {
 		printk (KERN_ERR "pci_pool_free %s/%s, dma %Lx already free\n",
-			pool->dev ? pool->dev->slot_name : NULL,
+			pool->dev ? pci_name(pool->dev) : NULL,
 			pool->name, (unsigned long long)dma);
 		return;
 	}
diff -Nru a/drivers/pci/quirks.c b/drivers/pci/quirks.c
--- a/drivers/pci/quirks.c	Mon Jul 14 16:55:17 2003
+++ b/drivers/pci/quirks.c	Mon Jul 14 16:55:17 2003
@@ -33,7 +33,7 @@
 	while ((d = pci_find_device(PCI_VENDOR_ID_INTEL, PCI_DEVICE_ID_INTEL_82371SB_0, d))) {
 		pci_read_config_byte(d, 0x82, &dlc);
 		if (!(dlc & 1<<1)) {
-			printk(KERN_ERR "PCI: PIIX3: Enabling Passive Release on %s\n", d->slot_name);
+			printk(KERN_ERR "PCI: PIIX3: Enabling Passive Release on %s\n", pci_name(d));
 			dlc |= 1<<1;
 			pci_write_config_byte(d, 0x82, dlc);
 		}
@@ -437,7 +437,7 @@
 
 	if (new_irq != irq) {
 		printk(KERN_INFO "PCI: Via IRQ fixup for %s, from %d to %d\n",
-		       dev->slot_name, irq, new_irq);
+		       pci_name(dev), irq, new_irq);
 
 		udelay(15);
 		pci_write_config_byte(dev, PCI_INTERRUPT_LINE, new_irq);
@@ -598,7 +598,7 @@
                return;
 
        printk(KERN_INFO "PCI: Ignoring BAR%d-%d of IDE controller %s\n",
-              first_bar, last_bar, dev->slot_name);
+              first_bar, last_bar, pci_name(dev));
 }
 
 /*
@@ -856,7 +856,7 @@
  		    (f->vendor == dev->vendor || f->vendor == (u16) PCI_ANY_ID) &&
  		    (f->device == dev->device || f->device == (u16) PCI_ANY_ID)) {
 #ifdef DEBUG
-			printk(KERN_INFO "PCI: Calling quirk %p for %s\n", f->hook, dev->slot_name);
+			printk(KERN_INFO "PCI: Calling quirk %p for %s\n", f->hook, pci_name(dev));
 #endif
 			f->hook(dev);
 		}
diff -Nru a/drivers/pci/setup-bus.c b/drivers/pci/setup-bus.c
--- a/drivers/pci/setup-bus.c	Mon Jul 14 16:55:17 2003
+++ b/drivers/pci/setup-bus.c	Mon Jul 14 16:55:17 2003
@@ -81,7 +81,7 @@
 	struct pci_bus_region region;
 
 	printk("PCI: Bus %d, cardbus bridge: %s\n",
-		bus->number, bridge->slot_name);
+		bus->number, pci_name(bridge));
 
 	pcibios_resource_to_bus(bridge, &region, bus->resource[0]);
 	if (bus->resource[0]->flags & IORESOURCE_IO) {
@@ -344,7 +344,7 @@
 			if (order > 11) {
 				printk(KERN_WARNING "PCI: region %s/%d "
 				       "too large: %lx-%lx\n",
-				       dev->slot_name, i, r->start, r->end);
+				       pci_name(dev), i, r->start, r->end);
 				r->flags = 0;
 				continue;
 			}
@@ -513,7 +513,7 @@
 
 		default:
 			printk(KERN_INFO "PCI: not setting up bridge %s "
-			       "for bus %d\n", dev->slot_name, b->number);
+			       "for bus %d\n", pci_name(dev), b->number);
 			break;
 		}
 	}
diff -Nru a/drivers/pci/setup-res.c b/drivers/pci/setup-res.c
--- a/drivers/pci/setup-res.c	Mon Jul 14 16:55:17 2003
+++ b/drivers/pci/setup-res.c	Mon Jul 14 16:55:17 2003
@@ -68,7 +68,7 @@
 
 	if ((new ^ check) & mask) {
 		printk(KERN_ERR "PCI: Error while updating region "
-		       "%s/%d (%08x != %08x)\n", dev->slot_name, resno,
+		       "%s/%d (%08x != %08x)\n", pci_name(dev), resno,
 		       new, check);
 	}
 
@@ -80,7 +80,7 @@
 		if (check != new) {
 			printk(KERN_ERR "PCI: Error updating region "
 			       "%s/%d (high %08x != %08x)\n",
-			       dev->slot_name, resno, new, check);
+			       pci_name(dev), resno, new, check);
 		}
 	}
 }
@@ -101,7 +101,7 @@
 		printk(KERN_ERR "PCI: %s region %d of %s %s [%lx:%lx]\n",
 		       root ? "Address space collision on" :
 			      "No parent found for",
-		       resource, dtype, dev->slot_name, res->start, res->end);
+		       resource, dtype, pci_name(dev), res->start, res->end);
 	}
 
 	return err;
@@ -139,7 +139,7 @@
 
 	if (ret) {
 		printk(KERN_ERR "PCI: Failed to allocate resource %d(%lx-%lx) for %s\n",
-		       resno, res->start, res->end, dev->slot_name);
+		       resno, res->start, res->end, pci_name(dev));
 	} else if (resno < PCI_BRIDGE_RESOURCES) {
 		pci_update_resource(dev, res, resno);
 	}
